import { IRenderMimeRegistry } from '@jupyterlab/rendermime';
import { KernelMessage, Kernel as JupyterKernel } from '@jupyterlab/services';
import { IExecuteReplyMsg, IExecuteRequestMsg } from '@jupyterlab/services/lib/kernel/messages';
import { Signal, ISignal } from '@lumino/signaling';
import { DataModel } from '@lumino/datagrid';
import { IVariableInspector } from './tokens';
import { KernelConnector } from './kernelconnector';
declare abstract class AbstractHandler implements IVariableInspector.IInspectable {
    private _isDisposed;
    private _disposed;
    protected _inspected: Signal<IVariableInspector.IInspectable, IVariableInspector.IVariableInspectorUpdate>;
    protected _connector: KernelConnector;
    protected _rendermime: IRenderMimeRegistry | null;
    constructor(connector: KernelConnector);
    get disposed(): ISignal<this, void>;
    get isDisposed(): boolean;
    get inspected(): ISignal<IVariableInspector.IInspectable, IVariableInspector.IVariableInspectorUpdate>;
    get rendermime(): IRenderMimeRegistry | null;
    abstract performInspection(): void;
    abstract performMatrixInspection(varName: string, maxRows: number): Promise<DataModel>;
    abstract performWidgetInspection(varName: string): JupyterKernel.IShellFuture<KernelMessage.IExecuteRequestMsg, KernelMessage.IExecuteReplyMsg>;
    dispose(): void;
    performDelete(varName: string): void;
}
/**
 * An object that handles code inspection.
 */
export declare class VariableInspectionHandler extends AbstractHandler {
    private _initScript;
    private _queryCommand;
    private _matrixQueryCommand;
    private _widgetQueryCommand;
    private _deleteCommand;
    private _ready;
    private _id;
    constructor(options: VariableInspectionHandler.IOptions);
    get id(): string;
    get ready(): Promise<void>;
    /**
     * Performs an inspection by sending an execute request with the query command to the kernel.
     */
    performInspection(): void;
    /**
     * Performs an inspection of a Jupyter Widget
     */
    performWidgetInspection(varName: string): JupyterKernel.IShellFuture<IExecuteRequestMsg, IExecuteReplyMsg>;
    /**
     * Performs an inspection of the specified matrix.
     */
    performMatrixInspection(varName: string, maxRows?: number): Promise<DataModel>;
    /**
     * Send a kernel request to delete a variable from the global environment
     */
    performDelete(varName: string): void;
    /**
     * Initializes the kernel by running the set up script located at _initScriptPath.
     */
    private _initOnKernel;
    private _handleQueryResponse;
    private _queryCall;
}
/**
 * A name space for inspection handler statics.
 */
export declare namespace VariableInspectionHandler {
    /**
     * The instantiation options for an inspection handler.
     */
    interface IOptions {
        connector: KernelConnector;
        rendermime?: IRenderMimeRegistry;
        queryCommand: string;
        matrixQueryCommand: string;
        widgetQueryCommand: string;
        deleteCommand: string;
        initScript: string;
        id: string;
    }
}
export declare class DummyHandler extends AbstractHandler {
    constructor(connector: KernelConnector);
    performInspection(): void;
    performMatrixInspection(varName: string, maxRows: number): Promise<DataModel>;
    performWidgetInspection(varName: string): JupyterKernel.IShellFuture<KernelMessage.IExecuteRequestMsg, KernelMessage.IExecuteReplyMsg>;
}
export {};
