import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { useState } from 'react';
import { useDispatch } from 'react-redux';
import { Box, IconButton } from '@primer/react';
import { PlayIcon, ChevronUpIcon, ChevronDownIcon, SquareIcon, XIcon, } from '@primer/octicons-react';
import { notebookActions, selectActiveCell } from '../../NotebookRedux';
import { DATALAYER_CELL_HEADER_CLASS } from './CellSidebarWidget';
export const CellSidebarNew = (props) => {
    const { notebookId, cellId } = props;
    const [visible, setVisible] = useState(false);
    const dispatch = useDispatch();
    const activeCell = selectActiveCell(notebookId);
    const layout = activeCell?.layout;
    if (layout) {
        const cellWidget = layout.widgets[0];
        if (cellWidget?.node.id === cellId) {
            if (!visible) {
                setVisible(true);
            }
        }
        if (cellWidget?.node.id !== cellId) {
            if (visible) {
                setVisible(false);
            }
        }
    }
    if (!visible) {
        return _jsx("div", {});
    }
    return activeCell ? (_jsxs(Box, { className: DATALAYER_CELL_HEADER_CLASS, sx: {
            '& p': {
                marginBottom: '0 !important',
            },
        }, children: [_jsx("span", { style: { display: 'flex' }, children: _jsx(IconButton, { size: "small", color: "secondary", "aria-label": "Run cell", title: "Run cell", onClick: e => {
                        e.preventDefault();
                        dispatch(notebookActions.run.started(notebookId));
                    }, icon: PlayIcon, variant: "invisible" }) }), _jsx("span", { style: { display: 'flex' }, children: _jsx(IconButton, { size: "small", color: "secondary", "aria-label": "Add code cell above", title: "Add code cell above", onClick: e => {
                        e.preventDefault();
                        dispatch(notebookActions.insertAbove.started({
                            uid: notebookId,
                            cellType: 'code',
                        }));
                    }, icon: ChevronUpIcon, variant: "invisible" }) }), _jsx("span", { style: { display: 'flex' }, children: _jsx(IconButton, { size: "small", color: "secondary", "aria-label": "Add markdown cell above", title: "Add markdown cell above", onClick: e => {
                        e.preventDefault();
                        dispatch(notebookActions.insertAbove.started({
                            uid: notebookId,
                            cellType: 'markdown',
                        }));
                    }, icon: ChevronUpIcon, variant: "invisible" }) }), _jsx("span", { style: { display: 'flex' }, children: activeCell.model.type === 'code' ? (_jsx(IconButton, { "aria-label": "Convert to markdow cell", title: "Convert to markdow cell", icon: SquareIcon, size: "small", variant: "invisible", onClick: e => {
                        e.preventDefault();
                        dispatch(notebookActions.changeCellType.started({
                            uid: notebookId,
                            cellType: 'markdown',
                        }));
                    } })) : (_jsx(IconButton, { "aria-label": "Convert to code cell", title: "Convert to code cell", icon: SquareIcon, variant: "invisible", size: "small", onClick: (e) => {
                        e.preventDefault();
                        dispatch(notebookActions.changeCellType.started({
                            uid: notebookId,
                            cellType: 'code',
                        }));
                    } })) }), _jsx("span", { style: { display: 'flex' }, children: _jsx(IconButton, { size: "small", color: "secondary", "aria-label": "Add markdown cell below", title: "Add markdown cell below", onClick: e => {
                        e.preventDefault();
                        dispatch(notebookActions.insertBelow.started({
                            uid: notebookId,
                            cellType: 'markdown',
                        }));
                    }, icon: ChevronDownIcon, variant: "invisible" }) }), _jsx("span", { style: { display: 'flex' }, children: _jsx(IconButton, { size: "small", color: "secondary", "aria-label": "Add code cell above", title: "Add code cell above", onClick: e => {
                        e.preventDefault();
                        dispatch(notebookActions.insertBelow.started({
                            uid: notebookId,
                            cellType: 'code',
                        }));
                    }, icon: ChevronDownIcon, variant: "invisible" }) }), _jsx("span", { style: { display: 'flex' }, children: _jsx(IconButton, { size: "small", color: "error", "aria-label": "Delete cell", title: "Delete cell", onClick: e => {
                        e.preventDefault();
                        dispatch(notebookActions.delete.started(notebookId));
                    }, icon: XIcon, variant: "invisible" }) })] })) : (_jsx(_Fragment, {}));
};
export default CellSidebarNew;
//# sourceMappingURL=CellSidebarButton.js.map